==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/utils/e2_button.c <==
/* $Id: e2_button.c 762 2005-05-13 04:00:38Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include "e2_button.h"

E2_Button E2_BUTTON_OK =
	{ "",N_("_Ok"),GTK_STOCK_OK,
		E2_BTN_DEFAULT,E2_BTN_DEFAULT,GTK_RESPONSE_OK};
E2_Button E2_BUTTON_CANCEL =
	{ "",N_("_Cancel"),GTK_STOCK_CANCEL, 0, 0, GTK_RESPONSE_CANCEL};
E2_Button E2_BUTTON_YES = 
	{ "",N_("_Yes"),GTK_STOCK_YES,E2_BTN_DEFAULT,E2_BTN_DEFAULT,GTK_RESPONSE_YES};
E2_Button E2_BUTTON_NO =
	{ "",N_("_No"),GTK_STOCK_NO,0,0,GTK_RESPONSE_NO};
E2_Button E2_BUTTON_YESTOALL =
//	{ "",N_("Yes to _all"),GTK_STOCK_APPLY,0,0,E2_RESPONSE_YESTOALL};
	{ "",N_("Yes to _all"),ICON_DIR"apply_all_"E2IP".png",0,0,E2_RESPONSE_YESTOALL};
E2_Button E2_BUTTON_NOTOALL =
	{ "",N_("_Stop"),GTK_STOCK_STOP,0,0,E2_RESPONSE_NOTOALL};
E2_Button E2_BUTTON_APPLY = 
	{ "",N_("_Apply"),GTK_STOCK_APPLY,0,0,GTK_RESPONSE_APPLY};
E2_Button E2_BUTTON_APPLYTOALL = 
//	{ "",N_("_Apply to all"),GTK_STOCK_APPLY,0,0,E2_RESPONSE_APPLYTOALL};
	{ "",N_("_Apply to all"),ICON_DIR"apply_all_"E2IP".png",0,0,E2_RESPONSE_APPLYTOALL};
E2_Button E2_BUTTON_REFRESH = 
	{ "",N_("_Refresh"),GTK_STOCK_REFRESH,0,0,E2_RESPONSE_REFRESH};
E2_Button E2_BUTTON_CLOSE = 
	{ "",N_("_Close"),GTK_STOCK_CLOSE,0,0,GTK_RESPONSE_CLOSE};
E2_Button E2_BUTTON_CREATE = 
	{ "",N_("_Create"),GTK_STOCK_YES,0,0,E2_RESPONSE_CREATE};  //check no co-use with close
E2_Button E2_BUTTON_REMOVE =
	{ "",N_("_Remove"),GTK_STOCK_REMOVE,0,0,E2_RESPONSE_REMOVE}; //check no co-use with refresh
	
void e2_button_setup_labels(void)
{
/*	E2_BUTTON_OK.default_label = _("_Ok");
	E2_BUTTON_CANCEL.default_label = _("_Cancel");
	E2_BUTTON_YES.default_label = _("_Yes");
	E2_BUTTON_NO.default_label = _("_No");
	E2_BUTTON_YESTOALL.default_label = _("Yes to _all");
	E2_BUTTON_NOTOALL.default_label = _("_Stop");
	E2_BUTTON_APPLY.default_label = _("_Apply");
	E2_BUTTON_APPLYTOALL.default_label = _("_Apply to all");
	E2_BUTTON_REFRESH.default_label = _("_Refresh");
	E2_BUTTON_CLOSE.default_label = _("_Close");
	E2_BUTTON_CREATE.default_label = _("_Create");
	E2_BUTTON_REMOVE.default_label = _("_Remove"); */

	E2_BUTTON_OK.label = gettext (E2_BUTTON_OK.default_label);
	E2_BUTTON_CANCEL.label = gettext (E2_BUTTON_CANCEL.default_label);
	E2_BUTTON_YES.label = gettext (E2_BUTTON_YES.default_label);
	E2_BUTTON_NO.label = gettext (E2_BUTTON_NO.default_label);
	E2_BUTTON_YESTOALL.label = gettext (E2_BUTTON_YESTOALL.default_label);
	E2_BUTTON_NOTOALL.label = gettext (E2_BUTTON_NOTOALL.default_label);
	E2_BUTTON_APPLY.label = gettext (E2_BUTTON_APPLY.default_label);
	E2_BUTTON_APPLYTOALL.label = gettext (E2_BUTTON_APPLYTOALL.default_label);
	E2_BUTTON_REFRESH.label = gettext (E2_BUTTON_REFRESH.default_label);
	E2_BUTTON_CLOSE.label = gettext (E2_BUTTON_CLOSE.default_label);
	E2_BUTTON_CREATE.label = gettext (E2_BUTTON_CREATE.default_label);
	E2_BUTTON_REMOVE.label = gettext (E2_BUTTON_REMOVE.default_label);
}

GtkWidget *e2_button_get (gchar *label, gchar *stock, gchar *tip,
	void *callback, void *data)
{
	GtkWidget *button = _e2_button_get (label, stock, GTK_ICON_SIZE_BUTTON,
		tip, callback, data, E2_BUTTON_CAN_DEFAULT | E2_BUTTON_CAN_FOCUS);
	gtk_widget_show_all (button);
	return button;
}

GtkWidget *_e2_button_get (gchar *label, gchar *stock, GtkIconSize size,
	gchar *tip, void *callback, void *data, E2_ButtonFlags flags)
{
	GtkWidget *button = gtk_button_new ();
	if (flags & E2_BUTTON_CAN_DEFAULT)
		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
	else
		GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_DEFAULT);
	if (flags & E2_BUTTON_CAN_FOCUS)
		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_FOCUS);
	else
		GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);

	if (callback != NULL)
		g_signal_connect_data (G_OBJECT (button), "clicked", G_CALLBACK (callback), data,
			(flags & E2_BUTTON_FREE_DATA) ? (GClosureNotify)  g_free : NULL, 0);

//	gfloat x_align;	
	GtkWidget *bbox;
	if (flags & E2_BUTTON_ICON_ABOVE_LABEL)
	{
//		x_align =  0.5;  //centre
		bbox = gtk_vbox_new (FALSE, E2_PADDING_XSMALL);
	}
	else
	{
//		x_align =  0.0;  //left-justify
		bbox = gtk_hbox_new (FALSE, E2_PADDING_XSMALL);
	}
//	GtkWidget *align = gtk_alignment_new (x_align, 0.5, 0.0, 0.0);
	GtkWidget *align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
	gtk_container_add (GTK_CONTAINER (align), bbox);

	gboolean need_align = FALSE;
	
	if (stock != NULL)
	{
		GtkWidget *img = e2_widget_get_icon (stock, size);
		if ((flags & E2_BUTTON_SHOW_MISSING_ICON) && (img == NULL))
			img = e2_widget_get_icon (GTK_STOCK_MISSING_IMAGE, size);
		if (img != NULL)
		{
			gtk_box_pack_start (GTK_BOX (bbox),
				img, FALSE, FALSE, 0);
			need_align = TRUE;
		}
	}

	if ((label != NULL) && (*label != '\0'))
	{
		GtkWidget *lab = gtk_label_new ("");
		gtk_label_set_markup_with_mnemonic (GTK_LABEL (lab), label);
		gtk_box_pack_end (GTK_BOX (bbox), lab, TRUE, TRUE, 0);
		gtk_misc_set_alignment (GTK_MISC (lab), 0.5, 0.5);
		need_align = TRUE;
	}

//	gtk_button_set_use_underline (GTK_BUTTON(button), TRUE); redundant - see above
	if (need_align)
		gtk_container_add (GTK_CONTAINER (button), align);
	e2_widget_set_tooltip (NULL, button, tip);

	return button;
}

GtkWidget *e2_button_add (GtkWidget *box, gboolean exp, guint pad, gchar *label,
	gchar *stock, gchar *tip, void *callback, void *data)
{
	GtkWidget *button = e2_button_get (label, stock, tip, callback, data);
	gtk_box_pack_start (GTK_BOX (box), button, exp, TRUE, pad);
	gtk_widget_show_all (button);
	return button;
}

GtkWidget *e2_button_add_end (GtkWidget *box, gboolean exp, guint pad, gchar *label,
	gchar *stock, gchar *tip, void *callback, void *data)
{
	GtkWidget *button = e2_button_get (label, stock, tip, callback, data);
	gtk_box_pack_end (GTK_BOX (box), button, exp, TRUE, pad);
	gtk_widget_show_all (button);
	return button;
}

GtkWidget *e2_button_get_toggle (gchar *label, gint state,
	void *func, gpointer data, gboolean check)
{
	GtkWidget *button;
	if (check)
		button = gtk_check_button_new_with_mnemonic (label);
	else
		button = gtk_toggle_button_new_with_mnemonic (label);
	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_FOCUS);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), state);
	if (func != NULL)
		g_signal_connect (G_OBJECT (button), "toggled",
			G_CALLBACK (func), data);
	return button;
}

GtkWidget *e2_button_add_toggle (GtkWidget *box, gchar *label, gint state,
	gboolean exp, guint pad, void *func, gpointer data, gboolean check)
{
	GtkWidget *button = e2_button_get_toggle (label, state, func, data, check);
	gtk_box_pack_start (GTK_BOX (box), button, exp, TRUE, pad);
	gtk_widget_show (button);
	return button;
}

GtkWidget *e2_button_add_radio (GtkWidget *box, gchar *label, GSList *group,
	gboolean exp, guint pad, void *func, gpointer data)
{
	GtkWidget *radio_button = gtk_radio_button_new_with_mnemonic (group, label);
	if (func != NULL)
		g_signal_connect (G_OBJECT (radio_button), "toggled",
			G_CALLBACK (func), data);
	gtk_box_pack_start (GTK_BOX (box), radio_button, exp, TRUE, pad);
	gtk_widget_show (radio_button);

	return radio_button;
}

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/src/utils/e2_button.c <==
/* $Id: e2_button.c 1310 2005-10-20 21:06:38Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "emelfm2.h"
#include "e2_button.h"

E2_Button E2_BUTTON_OK =
	{ "",N_("_Ok"),GTK_STOCK_OK,
		E2_BTN_DEFAULT,E2_BTN_DEFAULT,GTK_RESPONSE_OK};
E2_Button E2_BUTTON_CANCEL =
	{ "",N_("_Cancel"),GTK_STOCK_CANCEL, 0, 0, GTK_RESPONSE_CANCEL};
E2_Button E2_BUTTON_YES = 
	{ "",N_("_Yes"),GTK_STOCK_YES,E2_BTN_DEFAULT,E2_BTN_DEFAULT,GTK_RESPONSE_YES};
E2_Button E2_BUTTON_NO =
	{ "",N_("_No"),GTK_STOCK_NO,0,0,GTK_RESPONSE_NO};
E2_Button E2_BUTTON_YESTOALL =
//	{ "",N_("Yes to _all"),GTK_STOCK_APPLY,0,0,E2_RESPONSE_YESTOALL};
	{ "",N_("Yes to _all"),"apply_all_"E2IP".png",0,0,E2_RESPONSE_YESTOALL};
E2_Button E2_BUTTON_NOTOALL =
	{ "",N_("_Stop"),GTK_STOCK_STOP,0,0,E2_RESPONSE_NOTOALL};
E2_Button E2_BUTTON_APPLY = 
	{ "",N_("_Apply"),GTK_STOCK_APPLY,0,0,GTK_RESPONSE_APPLY};
E2_Button E2_BUTTON_APPLYTOALL = 
//	{ "",N_("_Apply to all"),GTK_STOCK_APPLY,0,0,E2_RESPONSE_APPLYTOALL};
	{ "",N_("_Apply to all"),"apply_all_"E2IP".png",0,0,E2_RESPONSE_APPLYTOALL};
E2_Button E2_BUTTON_REFRESH = 
	{ "",N_("_Refresh"),GTK_STOCK_REFRESH,0,0,E2_RESPONSE_REFRESH};
E2_Button E2_BUTTON_CLOSE = 
	{ "",N_("_Close"),GTK_STOCK_CLOSE,0,0,GTK_RESPONSE_CLOSE};
E2_Button E2_BUTTON_CREATE = 
	{ "",N_("_Create"),GTK_STOCK_YES,0,0,E2_RESPONSE_CREATE};  //check no co-use with close
E2_Button E2_BUTTON_REMOVE =
	{ "",N_("_Remove"),GTK_STOCK_REMOVE,0,0,E2_RESPONSE_REMOVE}; //check no co-use with refresh
	
void e2_button_setup_labels(void)
{
/*	E2_BUTTON_OK.default_label = _("_Ok");
	E2_BUTTON_CANCEL.default_label = _("_Cancel");
	E2_BUTTON_YES.default_label = _("_Yes");
	E2_BUTTON_NO.default_label = _("_No");
	E2_BUTTON_YESTOALL.default_label = _("Yes to _all");
	E2_BUTTON_NOTOALL.default_label = _("_Stop");
	E2_BUTTON_APPLY.default_label = _("_Apply");
	E2_BUTTON_APPLYTOALL.default_label = _("_Apply to all");
	E2_BUTTON_REFRESH.default_label = _("_Refresh");
	E2_BUTTON_CLOSE.default_label = _("_Close");
	E2_BUTTON_CREATE.default_label = _("_Create");
	E2_BUTTON_REMOVE.default_label = _("_Remove"); */

	E2_BUTTON_OK.label = gettext (E2_BUTTON_OK.default_label);
	E2_BUTTON_CANCEL.label = gettext (E2_BUTTON_CANCEL.default_label);
	E2_BUTTON_YES.label = gettext (E2_BUTTON_YES.default_label);
	E2_BUTTON_NO.label = gettext (E2_BUTTON_NO.default_label);
	E2_BUTTON_YESTOALL.label = gettext (E2_BUTTON_YESTOALL.default_label);
	E2_BUTTON_NOTOALL.label = gettext (E2_BUTTON_NOTOALL.default_label);
	E2_BUTTON_APPLY.label = gettext (E2_BUTTON_APPLY.default_label);
	E2_BUTTON_APPLYTOALL.label = gettext (E2_BUTTON_APPLYTOALL.default_label);
	E2_BUTTON_REFRESH.label = gettext (E2_BUTTON_REFRESH.default_label);
	E2_BUTTON_CLOSE.label = gettext (E2_BUTTON_CLOSE.default_label);
	E2_BUTTON_CREATE.label = gettext (E2_BUTTON_CREATE.default_label);
	E2_BUTTON_REMOVE.label = gettext (E2_BUTTON_REMOVE.default_label);
}

GtkWidget *e2_button_get (gchar *label, gchar *stock, gchar *tip,
	void *callback, void *data)
{
	GtkWidget *button = _e2_button_get (label, stock, GTK_ICON_SIZE_BUTTON,
		tip, callback, data, E2_BUTTON_CAN_DEFAULT | E2_BUTTON_CAN_FOCUS);
	gtk_widget_show_all (button);
	return button;
}

GtkWidget *_e2_button_get (gchar *label, gchar *stock, GtkIconSize size,
	gchar *tip, void *callback, void *data, E2_ButtonFlags flags)
{
	GtkWidget *button = gtk_button_new ();
	if (flags & E2_BUTTON_CAN_DEFAULT)
		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
	else
		GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_DEFAULT);
	if (flags & E2_BUTTON_CAN_FOCUS)
		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_FOCUS);
	else
		GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_FOCUS);

	if (callback != NULL)
		g_signal_connect_data (G_OBJECT (button), "clicked", G_CALLBACK (callback), data,
			(flags & E2_BUTTON_FREE_DATA) ? (GClosureNotify)  g_free : NULL, 0);

//	gfloat x_align;	
	GtkWidget *bbox;
	if (flags & E2_BUTTON_ICON_ABOVE_LABEL)
	{
//		x_align =  0.5;  //centre
		bbox = gtk_vbox_new (FALSE, E2_PADDING_XSMALL);
	}
	else
	{
//		x_align =  0.0;  //left-justify
		bbox = gtk_hbox_new (FALSE, E2_PADDING_XSMALL);
	}
//	GtkWidget *align = gtk_alignment_new (x_align, 0.5, 0.0, 0.0);
	GtkWidget *align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
	gtk_container_add (GTK_CONTAINER (align), bbox);

	gboolean need_align = FALSE;
	
	if (stock != NULL)
	{
		GtkWidget *img = e2_widget_get_icon (stock, size);
		if ((flags & E2_BUTTON_SHOW_MISSING_ICON) && (img == NULL))
			img = e2_widget_get_icon (GTK_STOCK_MISSING_IMAGE, size);
		if (img != NULL)
		{
			gtk_box_pack_start (GTK_BOX (bbox),
				img, FALSE, FALSE, 0);
			need_align = TRUE;
		}
	}

	if ((label != NULL) && (*label != '\0'))
	{
		GtkWidget *lab = gtk_label_new ("");
		gtk_label_set_markup_with_mnemonic (GTK_LABEL (lab), label);
		gtk_box_pack_end (GTK_BOX (bbox), lab, TRUE, TRUE, 0);
		gtk_misc_set_alignment (GTK_MISC (lab), 0.5, 0.5);
		need_align = TRUE;
	}

//	gtk_button_set_use_underline (GTK_BUTTON(button), TRUE); redundant - see above
	if (need_align)
		gtk_container_add (GTK_CONTAINER (button), align);
	e2_widget_set_tooltip (NULL, button, tip);

	return button;
}

GtkWidget *e2_button_add (GtkWidget *box, gboolean exp, guint pad, gchar *label,
	gchar *stock, gchar *tip, void *callback, void *data)
{
	GtkWidget *button = e2_button_get (label, stock, tip, callback, data);
	gtk_box_pack_start (GTK_BOX (box), button, exp, TRUE, pad);
	gtk_widget_show_all (button);
	return button;
}

GtkWidget *e2_button_add_end (GtkWidget *box, gboolean exp, guint pad, gchar *label,
	gchar *stock, gchar *tip, void *callback, void *data)
{
	GtkWidget *button = e2_button_get (label, stock, tip, callback, data);
	gtk_box_pack_end (GTK_BOX (box), button, exp, TRUE, pad);
	gtk_widget_show_all (button);
	return button;
}

GtkWidget *e2_button_get_toggle (gchar *label, gint state,
	void *func, gpointer data, gboolean check)
{
	GtkWidget *button;
	if (check)
		button = gtk_check_button_new_with_mnemonic (label);
	else
		button = gtk_toggle_button_new_with_mnemonic (label);
	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_FOCUS);
	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), state);
	if (func != NULL)
		g_signal_connect (G_OBJECT (button), "toggled",
			G_CALLBACK (func), data);
	return button;
}

GtkWidget *e2_button_add_toggle (GtkWidget *box, gchar *label, gint state,
	gboolean exp, guint pad, void *func, gpointer data, gboolean check)
{
	GtkWidget *button = e2_button_get_toggle (label, state, func, data, check);
	gtk_box_pack_start (GTK_BOX (box), button, exp, TRUE, pad);
	gtk_widget_show (button);
	return button;
}

GtkWidget *e2_button_add_radio (GtkWidget *box, gchar *label, GSList *group,
	gboolean exp, guint pad, void *func, gpointer data)
{
	GtkWidget *radio_button = gtk_radio_button_new_with_mnemonic (group, label);
	if (func != NULL)
		g_signal_connect (G_OBJECT (radio_button), "toggled",
			G_CALLBACK (func), data);
	gtk_box_pack_start (GTK_BOX (box), radio_button, exp, TRUE, pad);
	gtk_widget_show (radio_button);

	return radio_button;
}
